.. _examples:

=========
Examples
=========

Most module doc pages include relevant examples.

.. todo::

   Write script to walk the module tree, parse example content from docstrings,
   autogenerate literalincludes directive, and reproduce the content here.
